@@ -7,6 +7,7 @@ import org.gcube.common.homelibrary.home.workspace.WorkspaceFolder;
 import org.gcube.common.homelibrary.home.workspace.WorkspaceItem;
 import org.gcube.common.homelibrary.home.workspace.WorkspaceSharedFolder;
 import org.gcube.portal.databook.shared.ApplicationProfile;
+import org.gcube.portal.databook.shared.NotificationType;
 import org.gcube.portal.databook.shared.RunningJob;
 /**
  * 
@@ -129,10 +130,13 @@ public interface NotificationsManager {
 	/**
 	 * 
 	 * @param userIdToNotify the user you want to notify
+	 * @param messageUniqueIdentifier the unique identifier of the message
 	 * @param subject the subject of the message sent
+	 * @param messageText the text of the message (text/plain)
+	 * @param otherRecipientsFullNames the Full Names of the other recipients. if any
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyMessageReceived(String userIdToNotify, String subject);
+	boolean notifyMessageReceived(String userIdToNotify, String messageUniqueIdentifier, String subject, String messageText, String ... otherRecipientsFullNames);
 	/**
 	 * 
 	 * @param userIdToNotify the user you want to notify
@@ -178,9 +182,10 @@ public interface NotificationsManager {
 	 * @param userIdToNotify the user you want to notify
 	 * @param feedid the liked feedid 
 	 * @param feedText the liked feed text or a portion of it
+	 * @param commentKey when sending email, stop the shown discussion at that comment
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyOwnCommentReply(String userIdToNotify, String feedid, String feedText);
+	boolean notifyOwnCommentReply(String userIdToNotify, String feedid, String feedText, String commentKey);
 	/**
 	 * use to notify a user that commented on a post (Not his) that someone commented too 
 	 * 
@@ -188,27 +193,40 @@ public interface NotificationsManager {
 	 * @param feedid the liked feedid 
 	 * @param feedText the liked feed text or a portion of it
 	 * @param feedOwnerFullName the full name of the user who created this post
+	 * @param commentKey when sending email, stop the shown discussion at that comment
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyCommentReply(String userIdToNotify, String feedid, String feedText, String feedOwnerFullName, String feedOwnerId);
+	boolean notifyCommentReply(String userIdToNotify, String feedid, String feedText, String feedOwnerFullName, String feedOwnerId, String commentKey);
 	/**
-	 * use to notify a user that someone commented on one of his favorite posts 
+	 * @deprecated use notifyCommentOnLike
+	 * use to notify a user that someone commented on one of his liked posts 
 	 * 
 	 * @param userIdToNotify the user you want to notify
 	 * @param feedid the liked feedid 
 	 * @param commentText the commentText
+	 * @param commentKey when sending email, stop the shown discussion at that comment
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyCommentOnFavorite(String userIdToNotify, String feedid, String commentText);
+	boolean notifyCommentOnFavorite(String userIdToNotify, String feedid, String commentText, String commentKey);
+	/**
+	 * 
+	 * @param userIdToNotify the user you want to notify
+	 * @param feedid the liked feedid 
+	 * @param commentText the commentText
+	 * @param commentKey when sending email, stop the shown discussion at that comment
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyCommentOnLike(String userIdToNotify, String feedid, String commentText, String commentKey);
 	/**
 	 * use to notify a user that he was mentioned (tagged) on a post
 	 * 
 	 * @param userIdToNotify the user you want to notify
 	 * @param feedid the liked feedid 
 	 * @param feedText the liked feed text or a portion of it
+	 * @param commentKey when sending email, stop the shown discussion at that comment
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyUserTag(String userIdToNotify, String feedid, String commentText);
+	boolean notifyUserTag(String userIdToNotify, String feedid, String commentText, String commentKey);
 	/**
 	 * use to notify a user he got one of his post liked
 	 *  
@@ -226,63 +244,17 @@ public interface NotificationsManager {
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
 	boolean notifyJobStatus(String userIdToNotify, ApplicationProfile executingJobApId, RunningJob job);
+	
+	boolean notifyTDMTabularResourceSharing(String userIdToNotify, String tabularResourceName, String encodedTabularResourceParams) throws Exception;
 	/**
-	 * use to notify a document workflow owner that someone 
-	 * has viewed a document involved in a worflow he created
+	 * use to notify a user he got a Tabular Data Resource shared
+	 *
 	 * @param userIdToNotify the user you want to notify
-	 * @param documentName the document title
-	 * @param documentid the id of the document workflow
+	 * @param type type of the shared tdm object (TDM Rule or TDM Template at the moment)
+	 * @param tdmObjectName the name
+	 * @param encodedTabularResourceParams the parameters to be placed in the HTTP GET Request (must be encoded)
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyDocumentWorkflowView(String userIdToNotify, String documentWorkflowId, String documentName);
-	/**
-	 * use to notify a document workflow owner that someone 
-	 * has updated a document involved in a worflow he created
-	 * @param userIdToNotify the user you want to notify
-	 * @param documentName the document title
-	 * @param documentid the id of the document workflow
-	 * @return true if the notification is correctly delivered, false otherwise
-	 */
-	boolean notifyDocumentWorkflowUpdate(String userIdToNotify, String documentWorkflowId, String documentName);
-	/**
-	 * use to notify a document workflow user (user that in the same document workflow) 
-	 * that he is requested to do a task
-	 * @param userIdToNotify the user you want to notify
-	 * @param documentName the document title
-	 * @param documentid the id of the document workflow
-	 * @param isStartStep set to true is the document worflow was just created
-	 * @return true if the notification is correctly delivered, false otherwise
-	 */
-	boolean notifyDocumentWorkflowTaskRequest(String userIdToNotify, String documentWorkflowId, String documentName, String assignedRole);
-	/**
-	 * use to notify a document workflow user that a new Document Workflow was created and he is involved in the first step
-	 * and he is requested to do a task
-	 * @param userIdToNotify the user you want to notify
-	 * @param documentName the document title
-	 * @param documentid the id of the document workflow
-	 * @param isStartStep set to true is the document worflow was just created
-	 * @return true if the notification is correctly delivered, false otherwise
-	 */
-	boolean notifyDocumentWorkflowFirstStepRequest(String userIdToNotify, String documentWorkflowId, String documentName, String assignedRole);
-	/**
-	 * use to notify a document workflow owner that a user performed a forward action to another step a document worflow he created 
-	 * @param userIdToNotify the owner of this document workflow
-	 * @param documentWorkflowId
-	 * @param documentName
-	 * @param fromStepName the name of the step from which the user performed the forward
-	 * @param toStepName the name of the step to which the user performed the forward
-	 * @return  true if the notification is correctly delivered, false otherwise
-	 */
-	boolean notifyDocumentWorkflowUserForward(String userIdToNotify, String documentWorkflowId, String documentName, String fromStepName, String toStepName);
-	/**
-	 * use to notify a document workflow owner that someone  forwarded and the workflow moved to another step a document worflow he created
-	 * @param userIdToNotify the owner of this document workflow
-	 * @param documentWorkflowId
-	 * @param documentName
-	 * @param fromStepName the name of the step from which the user performed the forward
-	 * @param toStepName the name of the step to which the user performed the forward
-	 * @return true if the notification is correctly delivered, false otherwise
-	 */
-	boolean notifyDocumentWorkflowStepForwardComplete(String userIdToNotify, String documentWorkflowId, String documentName, String fromStepName, String toStepName);
+	boolean notifyTDMObjectSharing(String userIdToNotify, NotificationType type, String tdmObjectName, String encodedTabularResourceParams) throws Exception;
 	
 }
